lcvtoolbox.vision.geometry.primitives.quaternion.RotationMatrix
===============================================================

.. currentmodule:: lcvtoolbox.vision.geometry.primitives.quaternion

.. autoclass:: RotationMatrix
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~RotationMatrix.__init__
      ~RotationMatrix.align_vectors
      ~RotationMatrix.apply_to_vector
      ~RotationMatrix.compose
      ~RotationMatrix.copy
      ~RotationMatrix.distance_to
      ~RotationMatrix.from_axis_angle
      ~RotationMatrix.from_euler_angles
      ~RotationMatrix.from_quaternion
      ~RotationMatrix.from_rpy
      ~RotationMatrix.from_two_vectors
      ~RotationMatrix.identity
      ~RotationMatrix.interpolate
      ~RotationMatrix.inverse
      ~RotationMatrix.is_close
      ~RotationMatrix.power
      ~RotationMatrix.random
      ~RotationMatrix.to_axis_angle
      ~RotationMatrix.to_quaternion
      ~RotationMatrix.to_rpy
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RotationMatrix.determinant
      ~RotationMatrix.matrix
      ~RotationMatrix.trace
   
   